package # Hide from PAUSE
  DBIx::Class::SQLAHacks::MSSQL;

use warnings;
use strict;

use base qw( DBIx::Class::SQLMaker::MSSQL );

1;
